# Generated by roxygen2: do not edit by hand

S3method(censor_weights,SuperSurv)
S3method(coef,SuperSurv)
S3method(eval_times,SuperSurv)
S3method(event_weights,SuperSurv)
S3method(learner_names,SuperSurv)
S3method(predict,SuperSurv)
S3method(predict,surv.aorsf)
S3method(predict,surv.bart)
S3method(predict,surv.coxboost)
S3method(predict,surv.coxph)
S3method(predict,surv.gam)
S3method(predict,surv.gbm)
S3method(predict,surv.glmnet)
S3method(predict,surv.km)
S3method(predict,surv.parametric)
S3method(predict,surv.ranger)
S3method(predict,surv.rfsrc)
S3method(predict,surv.ridge)
S3method(predict,surv.rpart)
S3method(predict,surv.svm)
S3method(predict,surv.xgboost)
S3method(print,SuperSurv)
S3method(print,summary.SuperSurv)
S3method(selected_variables,SuperSurv)
S3method(summary,SuperSurv)
S3method(training_variables,SuperSurv)
export(SuperSurv)
export(censor_weights)
export(create_grid)
export(estimate_marginal_rmst)
export(eval_brier)
export(eval_cindex)
export(eval_summary)
export(eval_timeROC)
export(eval_times)
export(event_weights)
export(explain_kernel)
export(explain_survex)
export(learner_names)
export(list_wrappers)
export(plot_beeswarm)
export(plot_benchmark)
export(plot_calibration)
export(plot_dependence)
export(plot_global_importance)
export(plot_marginal_rmst_curve)
export(plot_patient_waterfall)
export(plot_predict)
export(plot_rmst_vs_obs)
export(plot_survival_heatmap)
export(screen.all)
export(screen.elasticnet)
export(screen.glmnet)
export(screen.marg)
export(screen.rfsrc)
export(screen.var)
export(selected_variables)
export(surv.aorsf)
export(surv.bart)
export(surv.coxboost)
export(surv.coxph)
export(surv.exponential)
export(surv.gam)
export(surv.gbm)
export(surv.glmnet)
export(surv.km)
export(surv.loglogistic)
export(surv.lognormal)
export(surv.parametric)
export(surv.ranger)
export(surv.rfsrc)
export(surv.ridge)
export(surv.rpart)
export(surv.svm)
export(surv.weibull)
export(surv.xgboost)
export(training_variables)
importFrom(dplyr,desc)
importFrom(magrittr,"%>%")
importFrom(nnls,nnls)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,var)
importFrom(survival,Surv)
