#' METABRIC Breast Cancer Dataset
#'
#' A subset of the Molecular Taxonomy of Breast Cancer International Consortium
#' (METABRIC) dataset to demonstrate the SuperSurv package. 9 Covariates: 4 gene indicators (MKI67, EGFR, PGR, and ERBB2) and 5 clinical features (age at diagnosis, and indicators for hormone treatment, radiotherapy, and chemotherapy)
#'
#' @format A data frame with the clinical and genomic variables:
#' \describe{
#'   \item{duration}{Survival time.}
#'   \item{event}{Event indicator (1 = event, 0 = censored).}
#'   \item{x0}{Feature x0.}
#'   \item{x1}{Feature x1.}
#'   \item{x2}{Feature x2.}
#'   \item{x3}{Feature x3.}
#'   \item{x4}{Feature x4.}
#'   \item{x5}{Feature x5.}
#'   \item{x6}{Feature x6.}
#'   \item{x7}{Feature x7.}
#'   \item{x8}{Feature x8.}
#' }
"metabric"
