% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SuperSurv-methods.R
\name{print.SuperSurv}
\alias{print.SuperSurv}
\title{Print a SuperSurv fit}
\usage{
\method{print}{SuperSurv}(x, digits = max(3L, getOption("digits") - 3L), ...)
}
\arguments{
\item{x}{A fitted object of class \code{"SuperSurv"}.}

\item{digits}{Number of significant digits to use for displayed weights.}

\item{...}{Additional arguments ignored.}
}
\value{
The input object \code{x}, invisibly.
}
\description{
Prints a concise description of a fitted \code{SuperSurv} object.
}
